#!/usr/bin/env python
# -*- encoding=utf8 -*-
 
VERSION ='1.0'
 
from setuptools import setup
 
setup(
    name='cbg-spider',
    version=VERSION,
    author='Albus McGonagall',
    author_email='cabbagelang@hotmail.com',
    packages=['./'],
        scripts=[],
        package_data={},
        install_requires=[],
    )